@@ -1,20 +1,13 @@
 from .concats import DomainLeftRightFrequency, TermLeftRightFrequencyAnalyzer
 from .cooccurrences import ContainerTermsAnalyzer, DomainContainerTerms
-from .occurrences import (
-    DomainLinguOccurrence,
-    DomainTermOccurrence,
-    LinguOccurrenceAnalyzer,
-    TermOccurrenceAnalyzer,
-)
+from .occurrences import DomainTermOccurrence, TermOccurrenceAnalyzer
 
 # isort: unique-list
 __all__ = [
     "ContainerTermsAnalyzer",
     "DomainContainerTerms",
     "DomainLeftRightFrequency",
-    "DomainLinguOccurrence",
     "DomainTermOccurrence",
-    "LinguOccurrenceAnalyzer",
     "TermLeftRightFrequencyAnalyzer",
     "TermOccurrenceAnalyzer",
 ]
