@@ -1,17 +1,18 @@
 from .base import BaseCandidateTermFilter
-from .concatenation import JapaneseConcatenationFilter, EnglishConcatenationFilter
-from .symbollike import JapaneseSymbolLikeFilter, EnglishSymbolLikeFilter
-from .propernoun import JapaneseProperNounFilter, EnglishProperNounFilter
-from .numeric import JapaneseNumericFilter, EnglishNumericFilter
+from .concatenation import EnglishConcatenationFilter, JapaneseConcatenationFilter
+from .numeric import EnglishNumericFilter, JapaneseNumericFilter
+from .propernoun import EnglishProperNounFilter, JapaneseProperNounFilter
+from .symbollike import EnglishSymbolLikeFilter, JapaneseSymbolLikeFilter
 
+# isort: unique-list
 __all__ = [
     "BaseCandidateTermFilter",
-    "JapaneseConcatenationFilter",
     "EnglishConcatenationFilter",
-    "JapaneseSymbolLikeFilter",
-    "EnglishSymbolLikeFilter",
-    "JapaneseProperNounFilter",
-    "EnglishProperNounFilter",
-    "JapaneseNumericFilter",
     "EnglishNumericFilter",
+    "EnglishProperNounFilter",
+    "EnglishSymbolLikeFilter",
+    "JapaneseConcatenationFilter",
+    "JapaneseNumericFilter",
+    "JapaneseProperNounFilter",
+    "JapaneseSymbolLikeFilter",
 ]
