@@ -1,9 +1,9 @@
-from typing import Dict, Any
+from typing import Any, Dict
 
 from .base import BaseSingleDomainRankingMethod
-from .rankingdata import FLRHRankingData
 from .collectors import FLRHRankingDataCollector
 from .rankers import FLRHRanker
+from .rankingdata import FLRHRankingData
 
 
 class FLRHMethod(BaseSingleDomainRankingMethod[FLRHRankingData]):
