@@ -1,9 +1,10 @@
+from .data import DomainTechnicalTermList, PageTechnicalTermList, PDFTechnicalTermList
 from .extractor import TechnicalTermExtractor
-from .data import DomainTechnicalTermList, PDFTechnicalTermList, PageTechnicalTermList
 
+# isort: unique-list
 __all__ = [
-    "TechnicalTermExtractor",
     "DomainTechnicalTermList",
     "PDFTechnicalTermList",
     "PageTechnicalTermList",
+    "TechnicalTermExtractor",
 ]
