@@ -20,40 +20,21 @@ class EnglishTokenizer(BaseLanguageTokenizer):
         self._model.select_pipes(enable=enable_pipes)
 
         self._en_regex = re.compile(ALPHABET_REGEX)
-        self._symbol_regex = re.compile(SYMBOL_REGEX)
+        self._symbol_regex = re.compile(rf"({SYMBOL_REGEX})")
 
     def inscope(self, text: str) -> bool:
         return self._en_regex.search(text) is not None
 
     def tokenize(self, text: str) -> List[Token]:
+        text = self._symbol_regex.sub(r" \1 ", text)
         return list(map(self._create_token, self._model(text)))
 
     def _create_token(self, token: Any) -> Token:
         if self._symbol_regex.fullmatch(token.text):
-            return Token(
-                "en",
-                token.text,
-                "SYM",
-                "*",
-                "*",
-                "*",
-                "SYM",
-                token.text,
-                token.text,
-                False,
-            )
+            return Token("en", token.text, "SYM", "*", "*", token.text)
 
         return Token(
-            "en",
-            token.text,
-            token.pos_,
-            token.tag_,
-            "*",
-            "*",
-            token.pos_,
-            token.lemma_.lower(),
-            token.shape_,
-            token.is_stop,
+            "en", token.text, token.pos_, token.tag_, "*", token.lemma_.lower()
         )
 
 
