@@ -14,7 +14,7 @@ from ..data import Token
 from .base import BaseLanguageTokenizer
 
 SPACES = re.compile(r"\s+")
-DELIM_SPASE = re.compile(rf"(?<={NOSPACE_REGEX}) (?={NOSPACE_REGEX})")
+DELIM_SPACE = re.compile(rf"(?<={NOSPACE_REGEX}) (?={NOSPACE_REGEX})")
 
 
 class JapaneseTokenizer(BaseLanguageTokenizer):
@@ -24,7 +24,7 @@ class JapaneseTokenizer(BaseLanguageTokenizer):
         self._model.select_pipes(enable=enable_pipes)
 
         self._ja_regex = re.compile(JAPANESE_REGEX)
-        self._symbol_regex = re.compile(SYMBOL_REGEX)
+        self._symbol_regex = re.compile(rf"({SYMBOL_REGEX})")
 
     def inscope(self, text: str) -> bool:
         return self._ja_regex.search(text) is not None
@@ -34,10 +34,11 @@ class JapaneseTokenizer(BaseLanguageTokenizer):
         orginal_space_pos = {
             match.start() - offset
             for offset, match in enumerate(re.finditer(r" ", text))
-            if DELIM_SPASE.match(text, match.start()) is not None
+            if DELIM_SPACE.match(text, match.start()) is not None
         }
 
-        text = DELIM_SPASE.sub("", text)
+        text = DELIM_SPACE.sub("", text)
+        text = self._symbol_regex.sub(r" \1 ", text)
         tokens = list(map(self._create_token, self._model(text)))
 
         if not orginal_space_pos:
@@ -54,18 +55,7 @@ class JapaneseTokenizer(BaseLanguageTokenizer):
         while i < num_token:
             if pos in orginal_space_pos:
                 pos += len(str(tokens[i]))
-                space = Token(
-                    "ja",
-                    " ",
-                    "空白",
-                    "*",
-                    "*",
-                    "*",
-                    "SPACE",
-                    " ",
-                    " ",
-                    False,
-                )
+                space = Token("ja", " ", "空白", "*", "*", " ")
                 tokens.insert(i, space)
                 i += 2
             else:
@@ -76,18 +66,7 @@ class JapaneseTokenizer(BaseLanguageTokenizer):
 
     def _create_token(self, token: Any) -> Token:
         if self._symbol_regex.fullmatch(token.text):
-            return Token(
-                "ja",
-                token.text,
-                "補助記号",
-                "一般",
-                "*",
-                "*",
-                "SYM",
-                token.text,
-                token.text,
-                False,
-            )
+            return Token("ja", token.text, "補助記号", "一般", "*", token.text)
 
         pos_with_categories = token.tag_.split("-")
         num_categories = len(pos_with_categories) - 1
@@ -95,20 +74,8 @@ class JapaneseTokenizer(BaseLanguageTokenizer):
         pos = pos_with_categories[0]
         category = pos_with_categories[1] if num_categories >= 1 else "*"
         subcategory = pos_with_categories[2] if num_categories >= 2 else "*"
-        subsubcategory = pos_with_categories[3] if num_categories >= 3 else "*"
 
-        return Token(
-            "ja",
-            token.text,
-            pos,
-            category,
-            subcategory,
-            subsubcategory,
-            token.pos_,
-            token.lemma_.lower(),
-            token.shape_,
-            token.is_stop,
-        )
+        return Token("ja", token.text, pos, category, subcategory, token.lemma_.lower())
 
 
 class JapaneseTokenClassifier:
